@@ -3,6 +3,7 @@
 
 # Workaround Python3.8 issue
 # https://github.com/marrow/mailer/issues/87
+# pylint: disable=C0413
 import sys
 sys.modules["cgi.parse_qsl"] = None
 from marrow.mailer import Message, Mailer
@@ -13,29 +14,27 @@ def send_report_mail(plain_text, settings):
 
     Arguments:
         plain_text {string} -- Report body in plain text
-        settings {object} -- Settings from the class Config
+        settings (dict) -- Settings from the class Config.Smtp
 
     Returns:
     """
 
-    report_text = '\n'.join(plain_text)
-
     mailer = Mailer({
         'manager.use': 'futures',
         'transport.use': 'smtp',
-        'transport.host': settings.smtp_host,
-        'transport.tls': settings.smtp_ssl,
+        'transport.host': settings['host'],
+        'transport.tls': settings['ssl'],
         'transport.debug': False,
-        'transport.username': settings.smtp_user,
-        'transport.password': settings.smtp_pass,
+        'transport.username': settings['username'],
+        'transport.password': settings['password'],
         'transport.max_messages_per_connection': 5
     })
 
     mailer.start()
 
-    message = Message(author=settings.smtp_from, to=settings.smtp_to)
-    message.subject = settings.smtp_subject
-    message.plain = report_text
+    message = Message(author=settings['mailfrom'], to=settings['mailto'])
+    message.subject = settings['subject']
+    message.plain = plain_text
 
     mailer.send(message)
     mailer.stop()
